import { UseResourceOptions } from "./resource";
import { Options } from "../types";
export interface UseFetchingOptions extends Options, UseResourceOptions {
}
export interface UseFetchingCallbackOptions extends Omit<Options, "startFetchAtFirstRender">, UseResourceOptions {
}
/**
 * For fetching data after invoke refetch
 *
 * @example
 *   const { data, refetch } = useFetching(() => fetchApi());
 *
 *   return <Button onClick={refetch} />;
 */
declare const useFetchingCallback: <T extends (...args: any) => any>(fetchFunc: T, options?: UseFetchingCallbackOptions | undefined) => {
    data: import("../types").AsyncReturnType<T> | undefined;
    error: Error | undefined;
    isLoading: boolean;
    refetch: (...args: Parameters<T>) => void;
};
/**
 * For fetching data based on state change
 *
 * @example
 *   const [amount] = useState(100);
 *   const { data, isLoading } = useFetching(() => fetchApi(amount), [amount]);
 */
declare const useFetching: <T extends (...args: any) => any>(fetchFunc: T, deps?: any[] | undefined, options?: UseFetchingOptions | undefined) => {
    data: import("../types").AsyncReturnType<T> | undefined;
    error: Error | undefined;
    isLoading: boolean;
    refetch: (...args: Parameters<T>) => void;
};
export { useFetching, useFetchingCallback };
//# sourceMappingURL=fetch.d.ts.map