"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFetchingCallback = exports.useFetching = void 0;
const resource_1 = require("./resource");
/**
 * For fetching data after invoke refetch
 *
 * @example
 *   const { data, refetch } = useFetching(() => fetchApi());
 *
 *   return <Button onClick={refetch} />;
 */
const useFetchingCallback = (fetchFunc, options) => {
    const { resource, refetch } = resource_1.useCreateResource(fetchFunc, [], {
        ...options,
        startFetchAtFirstRender: false,
    });
    const { data, error, isLoading } = resource_1.useResource(resource, options);
    return { data, error, isLoading, refetch };
};
exports.useFetchingCallback = useFetchingCallback;
/**
 * For fetching data based on state change
 *
 * @example
 *   const [amount] = useState(100);
 *   const { data, isLoading } = useFetching(() => fetchApi(amount), [amount]);
 */
const useFetching = (fetchFunc, 
/** Default is [] */
deps, options) => {
    const { resource, refetch } = resource_1.useCreateResource(fetchFunc, deps, options);
    const { data, error, isLoading } = resource_1.useResource(resource, {
        loadingStartDelay: options === null || options === void 0 ? void 0 : options.loadingStartDelay,
    });
    return { data, error, isLoading, refetch };
};
exports.useFetching = useFetching;
//# sourceMappingURL=fetch.js.map