import type { AsyncReturnType } from "./utils";
export declare const RESOURCE_PENDING = 0;
export declare const RESOURCE_RESOLVED = 1;
export declare const RESOURCE_REJECTED = 2;
declare type ResourceStatus = typeof RESOURCE_PENDING | typeof RESOURCE_RESOLVED | typeof RESOURCE_REJECTED | undefined;
export declare type Resource<T extends (...args: any) => any = (...args: any) => any, I = undefined> = {
    read(): AsyncReturnType<T> | undefined;
    preload(): void;
    status: ResourceStatus;
    isLoading: boolean;
    value: AsyncReturnType<T> | I | undefined;
    promise: (T extends Promise<any> ? T : T extends (...args: any) => Promise<infer U> ? Promise<U> : undefined) | undefined;
    error: Error | undefined;
};
export interface UseResourceResponse<T> {
    data: T | undefined;
    isLoading: boolean;
    error: Error | undefined;
}
export interface Options {
    isPreloadAfterCallRefetch?: boolean;
    /**
     * Set false to prevents fetching in the first step, just fetch after deps be
     * changed, or refetch called.
     *
     * Default is true.
     */
    startFetchAtFirstRender?: boolean;
    /**
     * If it is true, during api reFetching, data will keep previous data until
     * refetch ended and new data assign
     *
     * Default is false
     */
    keepDataAliveWhenFetching?: boolean;
}
export interface UseCreateResourceResponse<T extends (...args: any) => any> {
    resource: Resource<T, AsyncReturnType<T>>;
    refetch: (...args: Parameters<T>) => void;
}
export {};
//# sourceMappingURL=resource.d.ts.map